# [0.4.8](https://github.com/seriaati/hakushin-py/compare/v0.4.7..v0.4.8) - 2025-02-16

## Bug Fixes

- Fix temporary hakushin API issue - ([4b6e97f](https://github.com/seriaati/hakushin-py/commit/4b6e97f4b78edd061bed4f1df5bccece66e11ee4))
- Handle missing element and attack_type - ([cc40b2b](https://github.com/seriaati/hakushin-py/commit/cc40b2bc5ea14ddb5a980d537479df751be2cd08))
- Update rarity field to include 0 in UpgradeMaterial model - ([6894d40](https://github.com/seriaati/hakushin-py/commit/6894d40882e05a8ad41c3ff64cb7796ddf6400db))

## Miscellaneous Chores

- **(deps)** update astral-sh/ruff-action action to v2 ([#62](https://github.com/seriaati/hakushin-py/issues/62)) - ([88e3994](https://github.com/seriaati/hakushin-py/commit/88e39947cc9cef7e3a26be7ebe754e0babce60c1))
- **(deps)** lock file maintenance ([#63](https://github.com/seriaati/hakushin-py/issues/63)) - ([1d6fa37](https://github.com/seriaati/hakushin-py/commit/1d6fa376d05c60694eb9e9184a74566b7b41bb97))
- **(deps)** lock file maintenance ([#64](https://github.com/seriaati/hakushin-py/issues/64)) - ([30e3cfd](https://github.com/seriaati/hakushin-py/commit/30e3cfdbb09836b06119fd0473d9796696d16f0a))
- **(deps)** lock file maintenance ([#66](https://github.com/seriaati/hakushin-py/issues/66)) - ([744b656](https://github.com/seriaati/hakushin-py/commit/744b656fed683b6533d650dd445f4704234de5be))
- **(deps)** update astral-sh/setup-uv action to v5 ([#65](https://github.com/seriaati/hakushin-py/issues/65)) - ([746ac59](https://github.com/seriaati/hakushin-py/commit/746ac595c7226607ae02277db69a3e80e047fd0a))
- **(deps)** update astral-sh/ruff-action action to v3 ([#67](https://github.com/seriaati/hakushin-py/issues/67)) - ([c4ceabc](https://github.com/seriaati/hakushin-py/commit/c4ceabc53c122eea71ac8b3bfd31c3257de79e10))
- **(deps)** lock file maintenance ([#68](https://github.com/seriaati/hakushin-py/issues/68)) - ([84290aa](https://github.com/seriaati/hakushin-py/commit/84290aaf82e99f5b37686e79cdd97afd7d08696d))
- **(deps)** lock file maintenance ([#69](https://github.com/seriaati/hakushin-py/issues/69)) - ([08a0380](https://github.com/seriaati/hakushin-py/commit/08a0380e01ee20a727e82286208307a6ec383edf))
- **(deps)** lock file maintenance ([#70](https://github.com/seriaati/hakushin-py/issues/70)) - ([4181cd1](https://github.com/seriaati/hakushin-py/commit/4181cd15bb32a5a990766cb32fd6969e0cfe0dfc))

